#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 tamarin-prover-accountability
version:              1.12.0
visibility:           public
id:                   tamarin-prover-accountability-1.12.0-FNISA2oEZ012DRGcDnyW2j
key:                  tamarin-prover-accountability-1.12.0-FNISA2oEZ012DRGcDnyW2j
license:              LicenseRef-GPL
copyright:            (c) 2019-2021 Robert Künnemann, Kevin Morio & Yavor Ivanov
maintainer:           Robert Künnemann <robert@kunnemann.de>
author:
    Robert Künnemann <robert@kunnemann.de>,
    Kevin Morio <kevin.morio@cispa.de>,
    Yavor Ivanov <yavor.ivanov@cispa.de>

homepage:             https://tamarin-prover.github.io/
synopsis:             Library for accountability for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides support for accountability verification.

category:             Theorem Provers
abi:                  fef8139fa7a1bdd279b9bd93a68a6977
exposed:              True
exposed-modules:      Accountability Accountability.Generation
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/tamarin-prover-accountability-1.12.0

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/tamarin-prover-accountability-1.12.0

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/tamarin-prover-accountability-1.12.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-tamarin-prover-accountability
hs-libraries:
    HStamarin-prover-accountability-1.12.0-FNISA2oEZ012DRGcDnyW2j

depends:
    aeson-2.2.2.0-CuqyF0GV84l91XsdnO7HOm
    aeson-pretty-0.8.10-ECTNSZBvfddKJSTE9dZot9 base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3 containers-0.6.7 deepseq-1.4.8.1
    dlist-1.0-HIzSgqRZHiKsjIDkWs7Jg exceptions-0.10.7 mtl-2.3.1
    parallel-3.2.2.0-4GFGhbl8Ae06nPoqdIyBUD parsec-3.1.16.1
    process-1.6.19.0 raw-strings-qq-1.1-KLrX2voo6SWEEx0NiRj8Jz
    safe-0.3.21-2iv11P1GTSG3w8ujmSn6bG
    tamarin-prover-term-1.12.0-BDzBKngpBvM3soXOSE9lSu
    tamarin-prover-theory-1.12.0-FR61DAbCDde6qvPjCqEWIB
    tamarin-prover-utils-1.12.0-9wSHJ9gg2aBHjJUU9X63kk text-2.0.2
    transformers-0.6.1.0 uniplate-1.6.13-3mQKQRBtHtD7nLeShKeSsN

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-accountability/html/tamarin-prover-accountability.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-accountability/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

